# Plover Melani

Italian system for Plover based on the Melani method.


## Documentation

For more information on the method, see: https://www.stenolab.it/ (in Italian).


## Release history

### 0.5.8

* first public release
